# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-Test-MockModule
Version:	0.179.0
Release:	1.%{__distinit}%{__distvers}
Summary:	Override subroutines in a module for unit testing
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/Test-MockModule
Source0:	https://cpan.metacpan.org/modules/by-module/Test/Test-MockModule-v%{version}.tar.gz
BuildArch:	noarch
# Build
BuildRequires:	coreutils
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(Module::Build) >= 0.4234
# Runtime
BuildRequires:	perl(Carp)
BuildRequires:	perl(Scalar::Util)
BuildRequires:	perl(strict)
BuildRequires:	perl(SUPER) >= 1.20
BuildRequires:	perl(vars)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(lib)
BuildRequires:	perl(parent)
BuildRequires:	perl(Test::More) >= 0.88
BuildRequires:	perl(Test::Warnings)
# Optional Tests
BuildRequires:	perl(Test::Pod) >= 1.00
BuildRequires:	perl(Test::Pod::Coverage) >= 1.00
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif

%description
Test::MockModule lets you temporarily redefine subroutines in other packages
for the purposes of unit testing.

A Test::MockModule object is set up to mock subroutines for a given module. The
object remembers the original subroutine so it can easily be restored. This
happens automatically when all MockModule objects for the given module go out
of scope, or when you unmock() the subroutine.

%prep
%setup -q -n Test-MockModule-v%{version}

%build
perl Build.PL --installdirs=vendor
./Build

%install
./Build install --destdir=%{buildroot} --create_packlist=0
%{_fixperms} -c %{buildroot}

%check
./Build test

%files
%license LICENSE
%doc Changes README.md
%{perl_vendorlib}/Test/
%{_mandir}/man3/Test::MockModule.3*

%changelog
* Fri Aug 30 2024 Paul Howarth <paul@city-fan.org> - 0.179.0-1
- Update to 0.179.0
  - Bump Module::Build requirement (GH#65)

* Mon Apr 29 2024 Paul Howarth <paul@city-fan.org> - 0.178.0-1
- Update to 0.178.0
  - Simplify CI workflow (GH#61)
  - Multiple improvements (GH#62)
  - Add protection to _replace_sub (GH#60)

* Thu Jun 29 2023 Paul Howarth <paul@city-fan.org> - 0.177.0-5
- Use SPDX-format license tag

* Wed Sep  8 2021 Paul Howarth <paul@city-fan.org> - 0.177.0-1
- Update to 0.177.0
  - Move test modules from build to test requires
- Fix dist tags for Alma and Rocky Linux

* Wed Jan  6 2021 Paul Howarth <paul@city-fan.org> - 0.176.0-1
- Update to 0.176.0
  - 'strict' mode is now lexically scoped
  - Update CI with dockerhub auth
  - Update GitHub workflow with deprecated add-path
- Use %%license unconditionally

* Fri Sep 18 2020 Paul Howarth <paul@city-fan.org> - 0.175.0-1
- Update to 0.175.0
  - Ignore CI files and whitesource (GH#50)

* Tue Sep 15 2020 Paul Howarth <paul@city-fan.org> - 0.174.0-1
- Update to 0.174.0
  - Fix typo in POD (GH#49)

* Sun Jun 14 2020 Paul Howarth <paul@city-fan.org> - 0.173.0-1
- Update to 0.173.0
  - Add warning when 'unmock' called without arguments
  - Import warned when using unknown argument
  - Fix Windows CI by installing SUPER

* Thu Feb 20 2020 Paul Howarth <paul@city-fan.org> - 0.172.0-1
- Update to 0.172.0
  - Make sure we can redefine a function in 'main'

* Mon Oct 21 2019 Paul Howarth <paul@city-fan.org> - 0.171.0-1
- Update to 0.171.0
  - Allow chaining of new with mock, redefine, define
  - redefine() no longer triggers errors if the object being mocked is not a
    hashref
  - Adds a define() method for mocking new functions that do not exist; throws
    an error if a function does exist
  - Adds 'strict' mode to prevent usage of noop() and mock() functions, and
    force the usage of define/redefine if desired
  - Mocking CORE::GLOBAL no longer throws errors indicating CORE::GLOBAL should
    have been installed/loaded

* Thu Jun  6 2019 Paul Howarth <paul@city-fan.org> - 0.170.0-3
- Perl 5.30 rebuild

* Mon Sep  3 2018 Paul Howarth <paul@city-fan.org> - 0.170.0-1
- Update to 0.170.0
  - Fixes an issue where warnings were thrown for mismatched prototypes, when
    mocking a prototyped function
  - Add CI pipeline for releasing to cpan
  - Pod: Provide a code snippet for original usage
  - Add missing pod entries
  - Fix versioning for semver conversion + PAUSE
- Switch upstream from search.cpan.org to metacpan.org

* Wed May  9 2018 Paul Howarth <paul@city-fan.org> - 0.15-1
- Update to 0.15
  - Fix LICENSE file content to match actual license
  - Ship t/redefine.t

* Tue May  8 2018 Paul Howarth <paul@city-fan.org> - 0.14-1
- Update to 0.14
  - Fixes a bug where the 'redefine()' function was dying when attempting to
    mock a function that was defined further up a module's inheritance chain;
    it now only dies when the mocked function does not exist in the module
    being mocked, or any of its parent modules

* Fri Oct  6 2017 Paul Howarth <paul@city-fan.org> - 0.13-1
- Update to 0.13
  - Added the 'redefine()' function, which works just like 'mock()', except
    that if the method being mocked doesn't exist, it causes a panic

* Thu Jul 13 2017 Paul Howarth <paul@city-fan.org> - 0.12-1
- Update to 0.12
  - Added the 'noop()' function to make mocking noops easier (GH#16)
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - Drop workaround for building with Test::More < 0.88

* Tue Oct  4 2016 Paul Howarth <paul@city-fan.org> - 0.11-3
- BR: perl-generators where available

* Mon Dec  7 2015 Paul Howarth <paul@city-fan.org> - 0.11-2
- Import from Fedora

* Wed Oct 28 2015 Tom Callaway <spot@fedoraproject.org> - 0.11-1
- Update to 0.11

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.10-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat Jun 06 2015 Jitka Plesnikova <jplesnik@redhat.com> - 0.10-2
- Perl 5.22 rebuild

* Tue Jun  2 2015 Tom Callaway <spot@fedoraproject.org> - 0.10-1
- Update to 0.10

* Fri Mar 27 2015 Tom Callaway <spot@fedoraproject.org> - 0.09-1
- Update to 0.09

* Wed Aug 27 2014 Jitka Plesnikova <jplesnik@redhat.com> - 0.05-22
- Perl 5.20 rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.05-21
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.05-20
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Sat Jul 20 2013 Petr Pisar <ppisar@redhat.com> - 0.05-19
- Perl 5.18 rebuild

* Sat Feb 23 2013 Ralf Corsépius <corsepiu@fedoraproject.org> - 0.05-19
- Add BR: perl(ExtUtils::MakeMaker) (Fix FTBFS #914317)
- Modernize spec

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.05-18
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Fri Jul 20 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.05-17
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Wed Jun 13 2012 Petr Pisar <ppisar@redhat.com> - 0.05-16
- Perl 5.16 rebuild

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.05-15
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Mon Jun 20 2011 Marcela Mašláňová <mmaslano@redhat.com> - 0.05-14
- Perl mass rebuild

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.05-13
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Wed Dec 08 2010 Ralf Corsépius <corsepiu@fedoraproject.org> - 0.05-12
- Add BR: perl(CGI) (Fix FTBFS: BZ 661082)

* Thu May 06 2010 Marcela Maslanova <mmaslano@redhat.com> - 0.05-11
- Mass rebuild with perl-5.12.0

* Fri Dec  4 2009 Stepan Kasal <skasal@redhat.com> - 0.05-10
- Rebuild against perl 5.10.1

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.05-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.05-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Wed Feb 27 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0.05-7
- Rebuild for perl 5.10 (again)

* Sun Jan 20 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0.05-6
- Rebuild for new perl

* Sun Aug 26 2007 Tom "spot" Callaway <tcallawa@redhat.com> - 0.05-5
- License tag fix

* Fri Sep 15 2006 Tom "spot" Callaway <tcallawa@redhat.com> - 0.05-4
- Bump for fc6

* Wed Jul 27 2005 Tom "spot" Callaway <tcallawa@redhat.com> - 0.05-3
- Add missing BuildRequires

* Fri Jul  8 2005 Tom "spot" Callaway <tcallawa@redhat.com> - 0.05-2
- Cleanups

* Wed Jul  6 2005 Tom "spot" Callaway <tcallawa@redhat.com> - 0.05-1
- Initial package for Fedora Extras
